@@ -215,10 +215,10 @@ gsm_logout_supports_system_suspend (GsmLogoutDialog *logout_dialog)
         if (LOGIND_RUNNING())
             ret = gsm_systemd_can_suspend (logout_dialog->priv->systemd);
 #endif
-#if defined(HAVE_SYSTEMD) && defined(HAVE_UPOWER)
+#if defined(HAVE_SYSTEMD) && defined(HAVE_UPOWER_HIBERNATE_SUSPEND)
         else
 #endif
-#ifdef HAVE_UPOWER
+#ifdef HAVE_UPOWER_HIBERNATE_SUSPEND
         ret = up_client_get_can_suspend (logout_dialog->priv->up_client);
 #endif
         return ret;
@@ -233,10 +233,10 @@ gsm_logout_supports_system_hibernate (GsmLogoutDialog *logout_dialog)
         if (LOGIND_RUNNING())
             ret = gsm_systemd_can_hibernate (logout_dialog->priv->systemd);
 #endif
-#if defined(HAVE_SYSTEMD) && defined(HAVE_UPOWER)
+#if defined(HAVE_SYSTEMD) && defined(HAVE_UPOWER_HIBERNATE_SUSPEND)
         else
 #endif
-#ifdef HAVE_UPOWER
+#ifdef HAVE_UPOWER_HIBERNATE_SUSPEND
         ret = up_client_get_can_hibernate (logout_dialog->priv->up_client);
 #endif
         return ret;
